==> tine20-allinone_2020.03.4.tar.bz2: Tasks/js/Tasks-lang-pl-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Polish (http://www.transifex.com/tine20/tine20/language/pl/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: pl\nPlural-Forms: nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "GENDER_Task, GENDER_Tasks"
: [
  ""
 ,""
 ,""
 ,""

]
, "Task, Tasks"
: [
  "Zadanie"
 ,"zadania"
 ,"zadania"
 ,"zadania"

]
, "Percent"
: "W procentach"

, "Completed"
: "Zakończone dnia"

, "Due"
: "Termin"

, "Class"
: ""

, "Description"
: "Opis"

, "Geo"
: ""

, "Location"
: ""

, "Organizer"
: "Notatnik elektroniczny"

, "Priority"
: "Priorytet"

, "Status, Status"
: [
  "Status"
 ,"statusy"
 ,"statusy"
 ,"statusy"

]
, "Lead"
: "Zapytanie wstępne"

, "Telephone"
: "Telefon"

, "Email"
: "E-mail"

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: "Należy podać prawidłową datę, ponieważ ustawiony jest alarm!"

, "Summary"
: "Streszczenie"

, "Due date"
: "Data ukończenia"

, "Add Responsible ..."
: "Dodaj osobę odpowiedzialną..."

, "Notes"
: "Notatki"

, "Enter description..."
: "Wprowadź opis..."

, "Percentage"
: "Procentowo"

, "Tasks"
: "Zadania"

, "to do list, to do lists"
: [
  "Lista zadań"
 ,"listy zadań"
 ,"listy zadań"
 ,"listy zadań"

]
, "to do lists"
: "listy zadań"

, "Quick Search"
: ""

, "Due Date"
: "Data zakończenia"

, "Responsible"
: "Osoba odpowiedzialna"

, "Last Modified Time"
: "Czas ostatniej zmiany"

, "Last Modified By"
: "Ostatnio zmienione przez"

, "Creation Time"
: "Czas utworzenia"

, "Created By"
: "Utworzone przez"

, "New Task"
: "Nowe zadanie"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Czy na pewno chcesz usunąć zaznaczone zadanie?"
 ,"Czy na pewno chcesz usunąć zaznaczone zadania?"
 ,"Czy na pewno chcesz usunąć zaznaczone zadania?"
 ,"Czy na pewno chcesz usunąć zaznaczone zadania?"

]
, "Attachments"
: ""

, "Tags"
: "Znaczniki"

, "Lead name"
: ""

, "Add a task..."
: "Dodaj zadanie..."

, "All my tasks"
: "Wszystkie moje zadania"

, "Default Favorite"
: "Domyślne ulubione"

, "The default favorite which is loaded on Tasks startup"
: "Domyślne, ulubione zadanie ładowane przy uruchamianiu zadań"

, "Default Task List"
: "Domyślna lista zadań"

, "The default task list to create new tasks in."
: "Domyślna lista zadań dla nowych zadań"

, "Tasks status available"
: "Dostępny status zadań"

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: "Status zadania: Możliwe. Zauważ proszę, że dodatkowy status zadania może wpływać w innych zadaniach na eksport albo synchronizację."

, "No response"
: "Brak odpowiedzi"

, "Cancelled"
: "Anulowane"

, "In process"
: "W opracowaniu"

, "Task priorities available"
: "Dostępne priorytety zadań"

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: "Możliwe priorytety zadań. Zauważ proszę, że podczas eksportu albo synchronizacji dodatkowe priorytety mogą mieć wpływ na inne systemy zadań."

, "low"
: "niski"

, "normal"
: "normalny"

, "high"
: "wysoki"

, "urgent"
: "pilny"

, "manage shared task lists"
: "edytowanie wspólnej listy zadań"

, "Create new shared tasks lists"
: "Utwórz nową, wspólną listę zadań"

, "manage shared tasks favorites"
: "zarządzanie ulubionymi ze wspólnych zadań"

, "Create or update shared tasks favorites"
: "Utwórz albo uaktualnij ulubione ze wspólnych zadań"

, "%s's personal tasks"
: "%s zadania własne"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: "Wszystkie zadania z mojej listy zadań"

, "My open tasks"
: "Moje, rozpoczęte zadania"

, "My open tasks this week"
: "Moje zadania rozpoczęte w tym tygodniu"

, "All tasks for me"
: "Zadania przypisane do mnie"

, "All tasks that I am responsible for"
: "Wszystkie zadania, za które odpowiadam"

, "Last modified by me"
: "Ostatnio zmienione przeze mnie"

, "All tasks that I have last modified"
: "Wszystkie zadania zmienione ostatnio przeze mnie"

, "Tasks without responsible"
: "Nieprzypisane zadania"

, "GENDER_Task"
: ""

, "Task"
: "Zadanie"

, "Status"
: "Status"

, "to do list"
: "Lista zadań"

, "Do you really want to delete the selected task?"
: "Czy na pewno chcesz usunąć zaznaczone zadanie?"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Tasks/js/Tasks-lang-pl-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Polish (http://www.transifex.com/tine20/tine20/language/pl/)\nLanguage: pl\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: "Należy podać prawidłową datę, ponieważ ustawiony jest alarm!"

, "Summary"
: "Streszczenie"

, "Due date"
: "Data ukończenia"

, "Priority"
: "Priorytet"

, "Organizer"
: "Notatnik elektroniczny"

, "Add Responsible ..."
: "Dodaj osobę odpowiedzialną..."

, "Notes"
: "Notatki"

, "Enter description..."
: "Wprowadź opis..."

, "Percentage"
: "Procentowo"

, "Status, Status"
: [
  "Status"
 ,"statusy"
 ,"statusy"
 ,"statusy"

]
, "Completed"
: "Zakończone dnia"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Czy na pewno chcesz usunąć zaznaczone zadanie?"
 ,"Czy na pewno chcesz usunąć zaznaczone zadania?"
 ,"Czy na pewno chcesz usunąć zaznaczone zadania?"
 ,"Czy na pewno chcesz usunąć zaznaczone zadania?"

]
, "Attachments"
: ""

, "Tags"
: "Znaczniki"

, "Lead name"
: ""

, "Add a task..."
: "Dodaj zadanie..."

, "Due Date"
: "Data zakończenia"

, "Percent"
: "W procentach"

, "Responsible"
: "Osoba odpowiedzialna"

, "Task, Tasks"
: [
  "Zadanie"
 ,"zadania"
 ,"zadania"
 ,"zadania"

]
, "Tasks"
: "Zadania"

, "to do list, to do lists"
: [
  "Lista zadań"
 ,"listy zadań"
 ,"listy zadań"
 ,"listy zadań"

]
, "to do lists"
: "listy zadań"

, "Quick Search"
: ""

, "Last Modified Time"
: "Czas ostatniej zmiany"

, "Last Modified By"
: "Ostatnio zmienione przez"

, "Creation Time"
: "Czas utworzenia"

, "Created By"
: "Utworzone przez"

, "New Task"
: "Nowe zadanie"

, "All my tasks"
: "Wszystkie moje zadania"

, "Default Favorite"
: "Domyślne ulubione"

, "The default favorite which is loaded on Tasks startup"
: "Domyślne, ulubione zadanie ładowane przy uruchamianiu zadań"

, "Default Task List"
: "Domyślna lista zadań"

, "The default task list to create new tasks in."
: "Domyślna lista zadań dla nowych zadań"

, "Enable Standard Alarm"
: ""

, "New task get a standard alarm as defined below"
: ""

, "Standard Alarm Time"
: ""

, "Minutes before the task ends"
: ""

, "Tasks status available"
: "Dostępny status zadań"

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: "Status zadania: Możliwe. Zauważ proszę, że dodatkowy status zadania może wpływać w innych zadaniach na eksport albo synchronizację."

, "No response"
: "Brak odpowiedzi"

, "Cancelled"
: "Anulowane"

, "In process"
: "W opracowaniu"

, "Task priorities available"
: "Dostępne priorytety zadań"

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: "Możliwe priorytety zadań. Zauważ proszę, że podczas eksportu albo synchronizacji dodatkowe priorytety mogą mieć wpływ na inne systemy zadań."

, "low"
: "niski"

, "normal"
: "normalny"

, "high"
: "wysoki"

, "urgent"
: "pilny"

, "%s's personal tasks"
: "%s zadania własne"

, "GENDER_Task"
: ""

, "Due"
: "Termin"

, "Class"
: ""

, "Description"
: "Opis"

, "Geo"
: ""

, "Location"
: ""

, "Lead"
: "Zapytanie wstępne"

, "Telephone"
: "Telefon"

, "Email"
: "E-mail"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: "Wszystkie zadania z mojej listy zadań"

, "My open tasks"
: "Moje, rozpoczęte zadania"

, "My open tasks this week"
: "Moje zadania rozpoczęte w tym tygodniu"

, "All tasks for me"
: "Zadania przypisane do mnie"

, "All tasks that I am responsible for"
: "Wszystkie zadania, za które odpowiadam"

, "Last modified by me"
: "Ostatnio zmienione przeze mnie"

, "All tasks that I have last modified"
: "Wszystkie zadania zmienione ostatnio przeze mnie"

, "Tasks without responsible"
: "Nieprzypisane zadania"

, "manage shared task lists"
: "edytowanie wspólnej listy zadań"

, "Create new shared tasks lists"
: "Utwórz nową, wspólną listę zadań"

, "manage shared tasks favorites"
: "zarządzanie ulubionymi ze wspólnych zadań"

, "Create or update shared tasks favorites"
: "Utwórz albo uaktualnij ulubione ze wspólnych zadań"

, "Status"
: "Status"

, "Do you really want to delete the selected task?"
: "Czy na pewno chcesz usunąć zaznaczone zadanie?"

, "Task"
: "Zadanie"

, "to do list"
: "Lista zadań"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
